<html>
<?php 
// script to update the database from 1.3.2

include ("slooze_local.php");

$ct = new MySloozeCtSql;

// update the topicscontent table
$ct->db->query("begin");
//$ct->db->query("set debug_print_query = true;");
$ct->db->query("alter table topicscontent add column direct boolean not null");
$ct->db->query("update topicscontent set direct = true where direct is null");
$pictures = $ct->getPictures();
reset($pictures);
while(list($key,$picture) = each($pictures)) {
	$pictureID = $picture['PictureID'];
	$topics = $ct->getTopicsOfPicture($pictureID);
	if (count($topics)==1) {
		$topic = $topics[0];
		if ($topic['TopicID']!=0) {
			$topic = $ct->getTopic($topic['ParentTopicID']);
			while(is_array($topic)) {
				$topicID = $topic['TopicID'];
				$ct->db->query("insert into topicscontent (TopicID,PictureID,Direct) ".
							   "values ($topicID,$pictureID,false)");
				echo "$pictureID -> $topicID : ".$topic['Description']."<br>";
				//			echo "parentTopic : ".$topic['ParentTopicID']."<br>";
				$topic = $ct->getTopic($topic['ParentTopicID']);
				if ($topic['TopicID']==0 && $topicID==0) {
					$topic = "";
				}
			}
		}
	}
}
$ct->db->query("commit");

page_close() ?>
</html>